@@ -17,10 +17,8 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-contrail \
     puppetlabs-concat \
     puppet-datacat \
-    puppet-ec2api \
     puppet-elasticsearch \
     puppetlabs-firewall \
-    konstantin-fluentd \
     puppet-galera \
     puppetlabs-git \
     puppet-glance \
@@ -34,28 +32,25 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-keystone \
     puppet-kibana3 \
     puppet-memcached \
-    puppet-mistral \
     puppetlabs-mysql \
     puppet-neutron \
     puppet-octavia \
     puppet-nova \
     puppet-oslo \
     puppet-nssdb \
-    puppet-opendaylight \
     puppet-ovn \
     puppet-puppet \
+    puppet-placement \
     puppet-qdr \
     puppetlabs-rabbitmq \
     puppet-redis \
     puppetlabs-rsync \
-    puppet-sahara \
     puppet-ssh \
     puppet-staging \
     puppetlabs-stdlib \
     puppet-swift \
     puppet-systemd \
     puppetlabs-sysctl \
-    puppet-timezone \
     puppetlabs-vcsrepo \
     puppet-vlan \
     puppet-vswitch \
@@ -63,7 +58,6 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-zookeeper \
     puppet-openstacklib \
     puppet-module-keepalived \
-    puppetlabs-ntp \
     puppet-snmp \
     puppet-tripleo \
     puppet-ironic \
@@ -73,12 +67,8 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppetlabs-corosync \
     puppet-pacemaker \
     puppet-manila \
-    puppet-uchiwa \
-    sensu-puppet \
     puppet-kmod \
     puppet-etcd \
-    puppet-zaqar \
-    puppet-veritas_hyperscale \
     puppet-ptp ; do
     export DIB_INSTALLTYPE_${module_name//\-/_}='source'
   done
